package
Version:
v0.0.0-...-f3538ee
Opens a new window with list of versions in this module.
Published: May 7, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Endpoint string `env:"API_ENDPOINT"`
Addr string `env:"IRC_ADDRESS"`
Nick string `env:"IRC_NICK"`
Pass string `env:"IRC_PASSWORD"`
User string `env:"IRC_USER"`
Name string `env:"IRC_FULLNAME"`
Channel string `env:"IRC_CHANNEL"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.